/*
 * OneWire.cpp
 *
 *  Created on: 23-08-2013
 *      Author: Wojtek
 */

#include "OneWire.h"

uint8_t OneWire::Reset() {
	ONE_WIRE_DIR_OUTPUT();
	ONE_WIRE_OUTPUT_LOW();
	_delay_us(485);
	ONE_WIRE_DIR_INPUT();
	_delay_us(35);
	if (bit_is_set(ONE_WIRE_PIN,ONE_WIRE_OUT)) {
		return 0;
	}
	_delay_us(470);
	if (bit_is_set(ONE_WIRE_PIN,ONE_WIRE_OUT)) {
		return 1;
	}
	return 0;
}

/*
 * Wysyla pojedynczy bit przez magistrale 1-wire
 */
void OneWire::SendBit(uint8_t bit) {
	ONE_WIRE_DIR_OUTPUT();
	ONE_WIRE_OUTPUT_LOW();
	_delay_us(5);
	if (bit)
		ONE_WIRE_DIR_INPUT();
	_delay_us(55);
	ONE_WIRE_DIR_INPUT();
}

/*
 * Wysyla pojedynczy bajt przez magistrale 1-wire
 */
void OneWire::SendByte(uint8_t byte) {
	uint8_t i;

	for (i = 0; i < 8; i++) {
		OneWire::SendBit((byte >> i) & 0x01);
	}

}

/*
 * Odczytuje jeden bit z magistrali 1-wire
 */

uint8_t OneWire::ReadBit(void) {
	ONE_WIRE_DIR_OUTPUT();
	ONE_WIRE_OUTPUT_LOW();
	_delay_us(2);
	ONE_WIRE_DIR_INPUT();
	_delay_us(15);
	return bit_is_set(ONE_WIRE_PIN,ONE_WIRE_OUT);
}

/*
 * Odczytuje jeden bajt z magistrali 1-wire
 */
uint8_t OneWire::ReadByte(void) {
	uint8_t data = 0, i;

	for (i = 0; i < 8; i++) {
		if (OneWire::ReadBit()) {
			data |= (1 << i);
		}
		_delay_us(15);
	}
	return data;
}

